@@ -51,6 +51,12 @@ class SQLOperator(Enum):
     FOREACH = auto()
 
 
+class PatternOperator(Enum):
+    START = auto()
+    END = auto()
+    CONTAINS = auto()
+
+
 class BooleanOperator(Enum):
     AND = auto()
     OR = auto()
